from vcCommand import *
import os.path

app = getApplication()
teach = getApplication().TeachContext

def SelectMode(args):
  if mode.Value == "Component":
    component.IsVisible = True
    componentFeature.IsVisible = False
  if mode.Value == "Component.Feature":
    componentFeature.IsVisible = True
    component.IsVisible = False

def OnStart():
  routine = teach.ActiveScope
  
  icon_path = getCommandPath()[8:]
  base, filename = os.path.split(icon_path)
  icon_path = os.path.join(base, 'rMaterialAssign.svg')
  
  processStatement = routine.addStatement(VC_STATEMENT_PROCESS, teach.ActiveStatementIndex + 1, icon_path)
  processStatement.Name = "Material"+str(teach.ActiveStatementIndex + 1)
  
  processStatement.createProperty(VC_STRING, 'Mode', VC_PROPERTY_STEP)
  processStatement.createProperty(VC_STRING, 'Component')
  processStatement.createProperty(VC_STRING, 'Component.Feature')
  processStatement.createProperty(VC_BUTTON, 'SelectTarget')
  processStatement.createProperty(VC_STRING, 'InitialMaterial')
  processStatement.createProperty('Ref<Material>', 'NewMaterial')
  processStatement.createProperty(VC_BOOLEAN, 'Reset')
  
  global mode, component, componentFeature, initialMaterial
  mode = processStatement.getProperty('Mode')
  component = processStatement.getProperty('Component')
  componentFeature = processStatement.getProperty('Component.Feature')
  initialMaterial = processStatement.getProperty('InitialMaterial')
  
  initialMaterial.WritableWhenConnected = False
  initialMaterial.WritableWhenDisconnected = False
  initialMaterial.WritableWhenSimulating = False
  
  component.IsVisible = False
  componentFeature.IsVisible = False
  
  mode.StepValues = ["Component","Component.Feature"]
  mode.OnChanged = SelectMode
  

  robot = teach.ActiveRobot 
  visibleStatementScriptName = 'StatementScript_' + processStatement.Name
  visibleStatementScript = robot.findBehaviour(visibleStatementScriptName)
  if not visibleStatementScript:
    visibleStatementScript = robot.createBehaviour(VC_PYTHONPROCESSHANDLER, visibleStatementScriptName)
  visibleStatementScript.Script = '''
from vcPythonProcessHandler import *
import vcVector

app = getApplication()
snap = app.findCommand('interactiveSnap') 

def ChildPicked(arg):
  global mode, component, componentFeature, newComponent, material
  if mode.Value == "Component":
    target = snap.TargetNode.Component
    component.Value = target.Name
    if target.Material != None:
      initialMaterial.Value = str(target.Material.Name)
  if mode.Value == "Component.Feature":
    newComponent = snap.TargetNode.Component
    target = snap.TargetGeoset.Feature
    componentFeature.Value = target.Name
    material = snap.TargetGeoset.Material
    if material != None:
      initialMaterial.Value = str(material.Name)

def OnPickComponent(arg):
  snap.clear()   
  snap.OnTargetSet = ChildPicked   
  snap.execute()

def hideOthers(statement):
  name = statement.getProperty('Name')
  name.IsVisible = False
  base = statement.getProperty('Base')
  base.IsVisible = False
  tool = statement.getProperty('Tool')
  tool.IsVisible = False

def setEvents(statement):
  global mode, component, componentFeature, initialMaterial, newMaterial, reset
  
  mode = statement.getProperty('Mode')
  component = statement.getProperty('Component')
  componentFeature = statement.getProperty('Component.Feature')
  initialMaterial = statement.getProperty('InitialMaterial')
  newMaterial = statement.getProperty('NewMaterial')
  reset = statement.getProperty('Reset')
  
  global selectTarget
  selectTarget = statement.getProperty('SelectTarget')
  if selectTarget:
    if not selectTarget.OnChanged:
      selectTarget.OnChanged = OnPickComponent

def OnStatementAdd(statement):
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)

def OnStatementModified(statement):
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)
  
def OnStatementExecute(executor, statement):  
  # Hide others
  hideOthers(statement)
  # Set events
  setEvents(statement)
  
  new_material = app.findMaterial(newMaterial.Value.Name) 
  if mode.Value == "Component":
    assembly = app.findComponent(component.Value)
    assembly.Material = new_material
  if mode.Value == "Component.Feature":
    assembly = app.findComponent(newComponent.Name)
    feature = assembly.findFeature(componentFeature.Value)
    geometrySets=feature.Geometry.GeometrySets
    for geometrySet in geometrySets:
      geometrySet.Material = new_material
    feature.rebuild()

def OnReset():
  if reset.Value == True:
    initial_material = app.findMaterial(initialMaterial.Value) 
    if mode.Value == "Component":
      assembly = app.findComponent(component.Value)
      assembly.Material = initial_material
    if mode.Value == "Component.Feature":
      assembly = app.findComponent(newComponent.Name)
      feature = assembly.findFeature(componentFeature.Value)
      geometrySets=feature.Geometry.GeometrySets
      for geometrySet in geometrySets:
        geometrySet.Material = initial_material
      feature.rebuild()



'''
  processStatement.Process = visibleStatementScript
  app.SelectionManager.setSelection(processStatement)

